@@ -5,8 +5,8 @@ import itertools
 import copy
 import functools
 import random
+from collections.abc import Mapping, Iterable
 
-from jaraco.classes.properties import NonDataProperty
 import jaraco.text
 
 
@@ -47,7 +47,7 @@ class Projection(collections.abc.Mapping):
     {'c': 3}
     """
 
-    def __init__(self, keys, space):
+    def __init__(self, keys: Iterable, space: Mapping):
         self._keys = set(keys)
         self._space = space
 
@@ -66,28 +66,16 @@ class Projection(collections.abc.Mapping):
         return len(self._keys_resolved())
 
 
-class DictFilter(collections.abc.Mapping):
+class DictFilter(Projection):
     """
-    Takes a dict, and simulates a sub-dict based on the keys.
+    Takes a dict and simulates a sub-dict based on a pattern.
 
-    >>> sample = {'a': 1, 'b': 2, 'c': 3}
-    >>> filtered = DictFilter(sample, ['a', 'c'])
-    >>> filtered == {'a': 1, 'c': 3}
-    True
-    >>> set(filtered.values()) == {1, 3}
-    True
-    >>> set(filtered.items()) == {('a', 1), ('c', 3)}
-    True
+    >>> sample = dict(a=1, b=2, c=3, d=4, ef=5)
 
-    One can also filter by a regular expression pattern
-
-    >>> sample['d'] = 4
-    >>> sample['ef'] = 5
-
-    Here we filter for only single-character keys
+    Filter for only single-character keys:
 
     >>> filtered = DictFilter(sample, include_pattern='.$')
-    >>> filtered == {'a': 1, 'b': 2, 'c': 3, 'd': 4}
+    >>> filtered == dict(a=1, b=2, c=3, d=4)
     True
 
     >>> filtered['e']
@@ -101,8 +89,8 @@ class DictFilter(collections.abc.Mapping):
     Pattern is useful for excluding keys with a prefix.
 
     >>> filtered = DictFilter(sample, include_pattern=r'(?![ace])')
-    >>> dict(filtered)
-    {'b': 2, 'd': 4}
+    >>> dict(filtered) == dict(b=2, d=4)
+    True
 
     Also note that DictFilter keeps a reference to the original dict, so
     if you modify the original dict, that could modify the filtered dict.
@@ -112,35 +100,13 @@ class DictFilter(collections.abc.Mapping):
     {'b': 2}
     """
 
-    def __init__(self, dict, include_keys=[], include_pattern=None):
-        self.dict = dict
-        self.specified_keys = set(include_keys)
-        if include_pattern is not None:
-            self.include_pattern = re.compile(include_pattern)
-        else:
-            # for performance, replace the pattern_keys property
-            self.pattern_keys = set()
-
-    def get_pattern_keys(self):
-        keys = filter(self.include_pattern.match, self.dict.keys())
-        return set(keys)
-
-    pattern_keys = NonDataProperty(get_pattern_keys)
+    def __init__(self, dict, *, include_pattern):
+        self._space = dict
+        self._include_pattern = re.compile(include_pattern)
 
     @property
-    def include_keys(self):
-        return self.specified_keys | self.pattern_keys
-
-    def __getitem__(self, i):
-        if i not in self.include_keys:
-            raise KeyError(i)
-        return self.dict[i]
-
-    def __iter__(self):
-        return filter(self.include_keys.__contains__, self.dict.keys())
-
-    def __len__(self):
-        return len(self.include_keys & self.dict.keys())
+    def _keys(self):
+        return set(filter(self._include_pattern.match, self._space))
 
 
 def dict_map(function, dictionary):
